@@ -3,6 +3,7 @@ import os
 import re
 import jinja2
 import venv
+import shutil
 from subprocess import Popen
 from glasskit.uorm.models.meta import snake_case
 
@@ -37,17 +38,26 @@ def find_project_name():
 def copy_sources(src_dir, dst_dir, appname):
     context = {"appname": appname}
     for srcname in os.listdir(src_dir):
+
         srcname = os.path.join(src_dir, srcname)
+        if srcname.endswith("__pycache__") or srcname.endswith(".pyc"):
+            continue
+
         dstname = os.path.join(dst_dir, os.path.basename(srcname))
         dstname = dstname.replace("__appname__", appname)
+
         if os.path.isdir(srcname):
             os.makedirs(dstname)
             copy_sources(srcname, dstname, appname)
         elif os.path.isfile(srcname):
-            with open(srcname) as tmplfile:
-                tmpl = jinja2.Template(tmplfile.read())
-                with open(dstname, "w") as outfile:
-                    outfile.write(tmpl.render(context))
+            if srcname.endswith(".tmpl"):
+                dstname = dstname[:-5]
+                with open(srcname) as tmplfile:
+                    tmpl = jinja2.Template(tmplfile.read())
+                    with open(dstname, "w") as outfile:
+                        outfile.write(tmpl.render(context))
+            else:
+                shutil.copy(srcname, dstname)
 
 
 def glasskit_directory():
@@ -71,9 +81,10 @@ def run_create(args):
     try:
         os.chdir(dirname)
         venv.create(args.venv, with_pip=True)
-        python_path = os.path.join(curr_dir, "venv/bin/pip3")
+        python_path = os.path.join(os.curdir, "venv/bin/pip3")
         p = Popen([python_path, 'install', '-r', 'requirements.txt'])
         p.wait()
+        os.chmod("glass.py", 0o755)
     finally:
         os.chdir(curr_dir)
 
